@@ -13,7 +13,6 @@ matplotlib.use('agg')
 import matplotlib.pyplot as plt
 import matplotlib_venn as venn
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -68,10 +67,15 @@ class ParsedVCF(pd.DataFrame):
             name = vcf.split('/')[-1]
         variantsDict = OrderedDict()
         for variant in pVCF:
-            variantsDict[variant.CHROM + '+' + str(variant.POS) + '+' + variant.REF + '+' + ','.join(variant.ALT)] = {
-                'ID': variant.ID, 'QUAL': variant.QUAL, 'FILTER': variant.FILTER}
+            variantsDict[variant.CHROM + '+' + str(
+                variant.POS) + '+' + variant.REF + '+' + ','.join(
+                variant.ALT)] = {
+                'ID': variant.ID, 'QUAL': variant.QUAL,
+                'FILTER': variant.FILTER}
             variantsDict[
-                variant.CHROM + '+' + str(variant.POS) + '+' + variant.REF + '+' + ','.join(variant.ALT)].update(
+                variant.CHROM + '+' + str(
+                    variant.POS) + '+' + variant.REF + '+' + ','.join(
+                    variant.ALT)].update(
                 {k: v for (k, v) in variant.INFO})
 
         df1 = pd.DataFrame.from_dict(variantsDict, orient='index')
@@ -80,7 +84,7 @@ class ParsedVCF(pd.DataFrame):
         df1.index.names = ['CHROM', 'POS', 'REF', 'ALT']
         df1.reset_index(inplace=True)
         splitdf = df1.loc[df1['ALT'].str.contains(',') == True].copy()
-        if(len(splitdf) > 0):
+        if (len(splitdf) > 0):
             ALT = splitdf['ALT'].astype(str).str.split(
                 ',', n=1, expand=True).stack().rename('ALT')
             ALT.index = ALT.index.droplevel(-1)
@@ -101,7 +105,8 @@ class ParsedVCF(pd.DataFrame):
         for col in splitlist:
             odd[col] = odd[col].astype(str).str.split(',', n=1).str[0]
             even[col] = even[col].apply(lambda x:
-                                        x if len(str(x).split(',')) <= 1 else str(x).split(',', maxsplit=1)[1])
+                                        x if len(str(x).split(',')) <= 1 else
+                                        str(x).split(',', maxsplit=1)[1])
         splitdf = pd.concat([odd, even]).sort_index().replace(
             to_replace=['\(', '\)'], value='', regex=True)
         del odd, even
@@ -168,7 +173,9 @@ class ParsedVCF(pd.DataFrame):
             df1['sorter2'] = [x[0] == x[1]
                               for x in zip(df1['ALT'], df1['Allele'])]
             df1 = df1.sort_values(by=['CHROM', 'POS', 'sorter2', 'sorter'],
-                                  ascending=[True, True, False, True]).drop_duplicates(['CHROM', 'POS', 'REF', 'ALT'])
+                                  ascending=[True, True, False,
+                                             True]).drop_duplicates(
+                ['CHROM', 'POS', 'REF', 'ALT'])
             df1.drop(columns=['sorter', 'sorter2'], inplace=True)
             del IMPACT_SEVERITY
         df1.columns = df1.columns.str.upper()
@@ -180,8 +187,9 @@ class ParsedVCF(pd.DataFrame):
             df1.drop(columns='HET', inplace=True)
             df1.rename(columns={'HOM': 'ZIGOSITY'}, inplace=True)
         if 'ESP6500_MAF' in df1.columns:
-            df1[['ESP6500_MAF_EA', 'ESP6500_MAF_AA', 'ESP6500_MAF_ALL']] = df1['ESP6500_MAF'].str.split(',',
-                                                                                                        expand=True)
+            df1[['ESP6500_MAF_EA', 'ESP6500_MAF_AA', 'ESP6500_MAF_ALL']] = df1[
+                'ESP6500_MAF'].str.split(',',
+                                         expand=True)
             df1['ESP6500_MAF_EA'] = df1['ESP6500_MAF_EA'].apply(
                 divide, args=(100,))
             df1['ESP6500_MAF_AA'] = df1['ESP6500_MAF_AA'].apply(
@@ -191,13 +199,15 @@ class ParsedVCF(pd.DataFrame):
             df1.drop(columns=['ESP6500_MAF'], inplace=True)
         if 'ESP6500_PH' in df1.columns:
             df1[['POLYPHEN_PRED', 'POLYPHEN_SCORE']
-                ] = df1['ESP6500_PH'].str.split(':', 1, expand=True)
+            ] = df1['ESP6500_PH'].str.split(':', 1, expand=True)
             df1['POLYPHEN_PRED'] = df1['POLYPHEN_PRED'].str.strip(
                 '.').str.strip('.,')
             df1['POLYPHEN_SCORE'] = df1['POLYPHEN_SCORE'].str.split(',').str[0]
             df1.drop(columns=['ESP6500_PH'], inplace=True)
-            df1.rename(columns={'ANNOTATION': 'EFFECT', 'ANNOTATION_IMPACT': 'IMPACT', 'ID': 'RSID'},
-                       inplace=True)
+            df1.rename(
+                columns={'ANNOTATION': 'EFFECT', 'ANNOTATION_IMPACT': 'IMPACT',
+                         'ID': 'RSID'},
+                inplace=True)
         numcols = list()
         for x in pVCF.header_iter():
             if x.type == 'INFO':
@@ -205,14 +215,18 @@ class ParsedVCF(pd.DataFrame):
                     numcols.append(x['ID'])
         numcols += ['ESP6500_MAF_EA', 'ESP6500_MAF_AA', 'ESP6500_MAF_ALL']
         numcols = list(
-            set([x.upper() for x in numcols for y in df1.columns if x.upper() == y]))
+            set([x.upper() for x in numcols for y in df1.columns if
+                 x.upper() == y]))
         df1[numcols] = df1[numcols].apply(
             pd.to_numeric, errors='coerce', axis=1)
         df1 = df1.round(6)
 
         if ('CLINVAR_CLNSIG' in df1.columns):
-            clinvartranslation = {'255': 'other', '0': 'Uncertain significance', '1': 'not provided', '2': 'Benign',
-                                  '3': 'Likely Benign', '4': 'Likely pathogenic', '5': 'Pathogenic',
+            clinvartranslation = {'255': 'other',
+                                  '0': 'Uncertain significance',
+                                  '1': 'not provided', '2': 'Benign',
+                                  '3': 'Likely Benign',
+                                  '4': 'Likely pathogenic', '5': 'Pathogenic',
                                   '6': 'drug response',
                                   '7': 'histocompatibility'}
             for k, v in clinvartranslation.items():
@@ -256,18 +270,27 @@ class ParsedVCF(pd.DataFrame):
         return pvcfs
 
     def to_macrogen_xls(self, outpath):
-        macrogen_cols = ['CHROM', 'POS', 'REF', 'ALT', 'DP', 'AD', 'QUAL', 'MQ', 'Zygosity', 'FILTER', 'Effect',
-                         'IMPACT', 'Gene_Name', 'Feature_Type', 'Feature_ID', 'Transcript_BioType',
-                         'Rank/Total', 'HGVS.c', 'HGVS.p', 'REF_AA', 'ALT_AA', 'cDNA_pos/cDNA_length',
-                         'CDS_pos/CDS_length', 'AA_pos/AA_length', 'Distance', 'dbSNP142_ID', '1000Gp3_AF',
-                         '1000Gp3_AFR_AF', '1000Gp3_AMR_AF', '1000Gp3_EAS_AF', '1000Gp3_EUR_AF', '1000Gp3_SAS_AF',
-                         'ESP6500_MAF_EA', 'ESP6500_MAF_AA', 'ESP6500_MAF_ALL', 'SIFT_score', 'SIFT_pred',
-                         'Polyphen2_HDIV_score', 'Polyphen2_HDIV_pred', 'Polyphen2_HVAR_score', 'Polyphen2_HVAR_pred',
-                         'CLINVAR_CLNSIG', 'CLINVAR_CLNDSDB', 'CLINVAR_CLNDSDBID', 'CLINVAR_CLNDBN',
+        macrogen_cols = ['CHROM', 'POS', 'REF', 'ALT', 'DP', 'AD', 'QUAL',
+                         'MQ', 'Zygosity', 'FILTER', 'Effect',
+                         'IMPACT', 'Gene_Name', 'Feature_Type', 'Feature_ID',
+                         'Transcript_BioType',
+                         'Rank/Total', 'HGVS.c', 'HGVS.p', 'REF_AA', 'ALT_AA',
+                         'cDNA_pos/cDNA_length',
+                         'CDS_pos/CDS_length', 'AA_pos/AA_length', 'Distance',
+                         'dbSNP142_ID', '1000Gp3_AF',
+                         '1000Gp3_AFR_AF', '1000Gp3_AMR_AF', '1000Gp3_EAS_AF',
+                         '1000Gp3_EUR_AF', '1000Gp3_SAS_AF',
+                         'ESP6500_MAF_EA', 'ESP6500_MAF_AA', 'ESP6500_MAF_ALL',
+                         'SIFT_score', 'SIFT_pred',
+                         'Polyphen2_HDIV_score', 'Polyphen2_HDIV_pred',
+                         'Polyphen2_HVAR_score', 'Polyphen2_HVAR_pred',
+                         'CLINVAR_CLNSIG', 'CLINVAR_CLNDSDB',
+                         'CLINVAR_CLNDSDBID', 'CLINVAR_CLNDBN',
                          'CLINVAR_CLNREVSTAT', 'CLINVAR_CLNACC']
         self['chrsort'] = self['CHROM'].replace({'X': 30, 'Y': 40})
         df1 = self.sort_values(['chrsort', 'POS'])[
-            [x.upper() for x in macrogen_cols if x.upper() in self.columns]].copy()
+            [x.upper() for x in macrogen_cols if
+             x.upper() in self.columns]].copy()
         df1.to_excel(outpath)
 
     def panel(self, panel):
@@ -334,8 +357,10 @@ class ParsedVCF(pd.DataFrame):
         elif isinstance(vcf2, ParsedVCF):
             pvcf2 = vcf2
 
-        indcols = ['QUAL', 'FILTER', 'DP', 'FS', 'MQ', 'SOR', 'QD', 'SET', 'BASEQRANKSUM', 'CLIPPINGRANKSUM',
-                   'MQRANKSUM', 'READPOSRANKSUM', 'AC', 'SAMPLES_AF', 'MLEAC', 'MLEAF', 'DBSNPBUILDID']
+        indcols = ['QUAL', 'FILTER', 'DP', 'FS', 'MQ', 'SOR', 'QD', 'SET',
+                   'BASEQRANKSUM', 'CLIPPINGRANKSUM',
+                   'MQRANKSUM', 'READPOSRANKSUM', 'AC', 'SAMPLES_AF', 'MLEAC',
+                   'MLEAF', 'DBSNPBUILDID']
         indself = [x for x in indcols if x in self.columns]
         indpvcf2 = [x for x in indcols if x in pvcf2.columns]
         self.drop(columns=indself, inplace=True)
@@ -367,7 +392,8 @@ class ParsedVCF(pd.DataFrame):
             right = pvcf2
 
         # Hago el merge
-        mergedVCF = left.merge(right, on=['CHROM', 'POS', 'REF', 'ALT'], how='outer',
+        mergedVCF = left.merge(right, on=['CHROM', 'POS', 'REF', 'ALT'],
+                               how='outer',
                                suffixes=('_' + self.name, '_' + pvcf2.name),
                                indicator=indicator)
 
@@ -375,7 +401,8 @@ class ParsedVCF(pd.DataFrame):
         difcols = [x.replace('_' + self.name, '')
                    for x in mergedVCF.columns if '_' + self.name in x]
         eqcols = [x for x in difcols if any(
-            y in x for y in ['1000GP3', 'CLINVAR', 'ESP6500', 'RSID', 'POLYPHEN'])]
+            y in x for y in
+            ['1000GP3', 'CLINVAR', 'ESP6500', 'RSID', 'POLYPHEN'])]
         difcols = set(difcols) - set(eqcols)
         # columnas a eliminar
         dropcols = [x + '_' + self.name for x in difcols]
@@ -387,12 +414,14 @@ class ParsedVCF(pd.DataFrame):
         # combino las que deberían ser iguales
         for col in eqcols:
             mergedVCF[col] = mergedVCF[col + '_' +
-                                       self.name].combine_first(mergedVCF[col + '_' + pvcf2.name])
+                                       self.name].combine_first(
+                mergedVCF[col + '_' + pvcf2.name])
         # combino las que podrían ser diferentes, si son diferentes (para variantes en ambos archivos, no las combino.
         for col in difcols:
             if all(tmp[col + '_' + self.name] == tmp[col + '_' + pvcf2.name]):
                 mergedVCF[col] = mergedVCF[col + '_' +
-                                           self.name].combine_first(mergedVCF[col + '_' + pvcf2.name])
+                                           self.name].combine_first(
+                    mergedVCF[col + '_' + pvcf2.name])
             else:
                 dropcols.remove(col + '_' + self.name)
                 dropcols.remove(col + '_' + pvcf2.name)
@@ -401,7 +430,8 @@ class ParsedVCF(pd.DataFrame):
         # armo la columna indicadora para Duos y Trios
         if indicator == 'DUOS':
             mergedVCF['DUOS'].replace(
-                {'left_only': self.name, 'right_only': pvcf2.name, 'both': self.name + ':' + pvcf2.name}, inplace=True)
+                {'left_only': self.name, 'right_only': pvcf2.name,
+                 'both': self.name + ':' + pvcf2.name}, inplace=True)
             mergedVCF.rename(columns={'DUOS': 'VENN'}, inplace=True)
             names = ':'.join([self.name, pvcf2.name])
             _duos_stats(mergedVCF, names)
@@ -422,14 +452,19 @@ class ParsedVCF(pd.DataFrame):
         if indicator == 'TRIOS':
             mergedVCF['PATIENT'] = None
             mergedVCF['PATIENT'] = np.where(
-                mergedVCF['TRIOS'] == 'left_only', left.name, mergedVCF['PATIENT'])
-            mergedVCF['PATIENT'] = np.where((mergedVCF['TRIOS'] == 'both'), mergedVCF['VENN'] + ':' + left.name,
-                                            mergedVCF['PATIENT'])
-            mergedVCF['PATIENT'] = np.where((mergedVCF['TRIOS'] == 'right_only'), mergedVCF['VENN'],
+                mergedVCF['TRIOS'] == 'left_only', left.name,
+                mergedVCF['PATIENT'])
+            mergedVCF['PATIENT'] = np.where((mergedVCF['TRIOS'] == 'both'),
+                                            mergedVCF[
+                                                'VENN'] + ':' + left.name,
                                             mergedVCF['PATIENT'])
+            mergedVCF['PATIENT'] = np.where(
+                (mergedVCF['TRIOS'] == 'right_only'), mergedVCF['VENN'],
+                mergedVCF['PATIENT'])
             mergedVCF.drop(columns=['VENN', 'TRIOS'], inplace=True)
             mergedVCF.rename(
-                columns={'PATIENT': 'VENN', 'ZIGOSITY': 'ZIGOSITY_' + left.name}, inplace=True)
+                columns={'PATIENT': 'VENN',
+                         'ZIGOSITY': 'ZIGOSITY_' + left.name}, inplace=True)
             names = self.name + ':' + pvcf2.name
             _trios_stats(mergedVCF, names)
 
@@ -437,31 +472,38 @@ class ParsedVCF(pd.DataFrame):
                 names = names.split(':')
                 if VENNPLACE == 'A':
                     mergedVCF = mergedVCF[
-                        (mergedVCF['VENN'].str.contains(names[0])) & ~(mergedVCF['VENN'].str.contains(names[1])) & ~(
+                        (mergedVCF['VENN'].str.contains(names[0])) & ~(
+                            mergedVCF['VENN'].str.contains(names[1])) & ~(
                             mergedVCF['VENN'].str.contains(names[2]))]
                 elif VENNPLACE == 'B':
                     mergedVCF = mergedVCF[
-                        ~(mergedVCF['VENN'].str.contains(names[0])) & (mergedVCF['VENN'].str.contains(names[1])) & ~(
+                        ~(mergedVCF['VENN'].str.contains(names[0])) & (
+                            mergedVCF['VENN'].str.contains(names[1])) & ~(
                             mergedVCF['VENN'].str.contains(names[2]))]
                 elif VENNPLACE == 'C':
                     mergedVCF = mergedVCF[
-                        ~(mergedVCF['VENN'].str.contains(names[0])) & ~(mergedVCF['VENN'].str.contains(names[1])) & (
+                        ~(mergedVCF['VENN'].str.contains(names[0])) & ~(
+                            mergedVCF['VENN'].str.contains(names[1])) & (
                             mergedVCF['VENN'].str.contains(names[2]))]
                 elif VENNPLACE == 'A:B':
                     mergedVCF = mergedVCF[
-                        (mergedVCF['VENN'].str.contains(names[0])) & (mergedVCF['VENN'].str.contains(names[1])) & ~(
+                        (mergedVCF['VENN'].str.contains(names[0])) & (
+                            mergedVCF['VENN'].str.contains(names[1])) & ~(
                             mergedVCF['VENN'].str.contains(names[2]))]
                 elif VENNPLACE == 'A:C':
                     mergedVCF = mergedVCF[
-                        (mergedVCF['VENN'].str.contains(names[0])) & ~(mergedVCF['VENN'].str.contains(names[1])) & (
+                        (mergedVCF['VENN'].str.contains(names[0])) & ~(
+                            mergedVCF['VENN'].str.contains(names[1])) & (
                             mergedVCF['VENN'].str.contains(names[2]))]
                 elif VENNPLACE == 'B:C':
                     mergedVCF = mergedVCF[
-                        ~(mergedVCF['VENN'].str.contains(names[0])) & (mergedVCF['VENN'].str.contains(names[1])) & (
+                        ~(mergedVCF['VENN'].str.contains(names[0])) & (
+                            mergedVCF['VENN'].str.contains(names[1])) & (
                             mergedVCF['VENN'].str.contains(names[2]))]
                 elif VENNPLACE == 'A:B:C':
                     mergedVCF = mergedVCF[
-                        (mergedVCF['VENN'].str.contains(names[0])) & (mergedVCF['VENN'].str.contains(names[1])) & (
+                        (mergedVCF['VENN'].str.contains(names[0])) & (
+                            mergedVCF['VENN'].str.contains(names[1])) & (
                             mergedVCF['VENN'].str.contains(names[2]))]
                 else:
                     logger.error(
@@ -486,8 +528,10 @@ class ParsedVCF(pd.DataFrame):
             logger.info('Calculating General Statistics')
             vcfstats = self.groupby(colstats).size().to_frame(name='count')
             vcfstats.name = 'stats'
-            plt.pie([item for sublist in vcfstats.groupby('CHROM').count().values for item in sublist],
-                    labels=vcfstats.groupby('CHROM').size().index.values)
+            plt.pie(
+                [item for sublist in vcfstats.groupby('CHROM').count().values
+                 for item in sublist],
+                labels=vcfstats.groupby('CHROM').size().index.values)
             my_circle = plt.Circle((0, 0), 0.7, color='white')
             chromVars = plt.gcf()
             chromVars.gca().add_artist(my_circle)
@@ -548,19 +592,23 @@ class ParsedVCF(pd.DataFrame):
             {'bg_color': '#C6EFCE', 'font_color': '#006100', 'bold': True})
         datasheet.conditional_format(0, cols_selected.index('IMPACT'),
                                      len(self), cols_selected.index('IMPACT'),
-                                     {'type': 'text', 'criteria': 'containing', 'value': 'HIGH',
+                                     {'type': 'text', 'criteria': 'containing',
+                                      'value': 'HIGH',
                                       'format': highformat, })
         datasheet.conditional_format(0, cols_selected.index('IMPACT'),
                                      len(self), cols_selected.index('IMPACT'),
-                                     {'type': 'text', 'criteria': 'containing', 'value': 'MODIFIER',
+                                     {'type': 'text', 'criteria': 'containing',
+                                      'value': 'MODIFIER',
                                       'format': modformat})
         datasheet.conditional_format(0, cols_selected.index('IMPACT'),
                                      len(self), cols_selected.index('IMPACT'),
-                                     {'type': 'text', 'criteria': 'containing', 'value': 'MODERATE',
+                                     {'type': 'text', 'criteria': 'containing',
+                                      'value': 'MODERATE',
                                       'format': moderformat})
         datasheet.conditional_format(0, cols_selected.index('IMPACT'),
                                      len(self), cols_selected.index('IMPACT'),
-                                     {'type': 'text', 'criteria': 'containing', 'value': 'LOW', 'format': lowformat})
+                                     {'type': 'text', 'criteria': 'containing',
+                                      'value': 'LOW', 'format': lowformat})
         logger.info('Writing Excel File')
         self.to_excel(output, sheet_name='DATA',
                       merge_cells=False, index=False, header=True)
@@ -591,12 +639,14 @@ class ParsedVCF(pd.DataFrame):
             stats.to_excel(output, sheet_name='STATISTICS')
         except Exception as e:
             logger.error(
-                'Could not print statistics. Error was {}'.format(e), exc_info=True)
+                'Could not print statistics. Error was {}'.format(e),
+                exc_info=True)
         try:
             statsheet.insert_image('H2', './general.png')
         except Exception as e:
             logger.error(
-                'Could not print stats graphs. Error was {}'.format(e), exc_info=True)
+                'Could not print stats graphs. Error was {}'.format(e),
+                exc_info=True)
         if os.path.isfile('./venn.png'):
             statsheet.insert_image('H25', './venn.png')
         output.save()
@@ -608,5 +658,3 @@ class ParsedVCF(pd.DataFrame):
             os.remove('./venn.png')
         except:
             logger.debug('Could not remove venn.png')
-
-        
\ No newline at end of file
